Module identity

Module identity 

Identity management — re-exported from void-crypto.

See void_crypto::identity for the implementation.

Structs

Identity
An identity containing signing, recipient, and optional Nostr keys
ParsedIdentity
Parsed identity containing public keys and optional username.

Enums

IdentityError
Errors that can occur in identity operations

Functions

derive_repo_owner_signing_key
Derive a per-repo owner Ed25519 signing key from an identity seed and repo ID.
ecies_unwrap_key
Unwrap a repository key using the identity’s X25519 private key.
ecies_wrap_key
Wrap a repository key using ECIES for a recipient’s X25519 public key.