pub struct RemoveResult {
pub removed_name: Option<String>,
pub removed_signing_pubkey: SigningPubKey,
pub key_rotation_recommended: bool,
}Expand description
Result of removing a contributor.
Fields
removed_name: Option<String>The removed contributor’s name (if set).
removed_signing_pubkey: SigningPubKeyThe removed contributor’s signing public key.
key_rotation_recommended: boolWhether key rotation is recommended after this removal.
Key rotation is always recommended when removing contributors because they may have cached the unwrapped repo key.