Module diff

Module diff 

Diff engine for void

Computes file-level differences between commits, trees, and working directories.

Re-exports

pub use content::content_diff_commits;
pub use content::content_diff_index;
pub use content::content_diff_staged;
pub use content::content_diff_working;
pub use content::ContentDiff;
pub use content::DiffLine;
pub use content::Hunk;

Modules

content
Content-level diff generation.

Structs

DiffStats
Statistics about a diff.
FileDiff
Represents a single file difference.
ThreeWayDiff
Result of a three-way diff operation.
TreeDiff
Collection of file differences between two trees.

Enums

DiffKind
Type of change detected for a file.
Side
Which side made a change in a three-way diff.
ThreeWayStatus
Status of a file in a three-way diff.

Functions

diff_commits
Computes the diff between two commits.
diff_index
Computes the diff between the index and the working tree.
diff_staged
Computes diff between HEAD commit and the index.
diff_three_way
Computes a three-way diff between a base commit and two branch commits.
diff_working
Computes the diff between a commit and the working tree.

Type Aliases

Cid
A Cid that contains a multihash with an allocated size of 512 bits.