pub struct ShardDiagnostics {
pub file_to_shard: HashMap<String, u64>,
pub file_hashes: HashMap<String, ContentHash>,
pub shard_cids: HashMap<u64, String>,
pub shard_files: HashMap<u64, Vec<String>>,
pub shard_sizes: HashMap<u64, u64>,
pub dir_listing_counts: HashMap<u64, usize>,
}Expand description
Diagnostics snapshot for a sealed commit.
Fields
file_to_shard: HashMap<String, u64>File path → shard ID.
file_hashes: HashMap<String, ContentHash>File path → content hash.
shard_cids: HashMap<u64, String>Shard ID → CID string.
shard_files: HashMap<u64, Vec<String>>Shard ID → sorted file list.
shard_sizes: HashMap<u64, u64>Shard ID → compressed body size.
dir_listing_counts: HashMap<u64, usize>Shard ID → directory listing count.
Implementations
Sourceimpl ShardDiagnostics
impl ShardDiagnostics
Sourcepub fn from_manifest(
manifest: &TreeManifest,
metadata: &MetadataBundle,
) -> Result<Self>
pub fn from_manifest( manifest: &TreeManifest, metadata: &MetadataBundle, ) -> Result<Self>
Builds diagnostics from a TreeManifest (no shard decryption needed).
Sourcepub fn from_commit(
ctx: &VoidContext,
commit: &Commit,
metadata: &MetadataBundle,
reader: &CommitReader,
) -> Result<Self>
pub fn from_commit( ctx: &VoidContext, commit: &Commit, metadata: &MetadataBundle, reader: &CommitReader, ) -> Result<Self>
Builds diagnostics by loading the manifest from a commit.
Sourcepub fn from_metadata(
ctx: &VoidContext,
metadata: &MetadataBundle,
reader: &CommitReader,
) -> Result<Self>
pub fn from_metadata( ctx: &VoidContext, metadata: &MetadataBundle, reader: &CommitReader, ) -> Result<Self>
Convenience: loads HEAD commit and builds diagnostics.
Used by tests that have a VoidContext + MetadataBundle but not the commit object.
Sourcepub fn total_files(&self) -> usize
pub fn total_files(&self) -> usize
Returns the number of files indexed in the diagnostics snapshot.
Sourcepub fn shard_count(&self) -> usize
pub fn shard_count(&self) -> usize
Returns the number of shards with data in the snapshot.