pub enum CommitHealth {
Healthy,
Partial {
missing: usize,
corrupt: usize,
},
Broken {
reason: String,
},
}Expand description
Health status of a single commit.
Variants
Healthy
All objects for this commit are present and valid.
Partial
Some objects are missing or corrupt, but commit is readable.
Fields
Broken
Commit itself cannot be read or decrypted.