fetch_published_commit

Function fetch_published_commit 

pub fn fetch_published_commit(opts: ImportOptions) -> Result<ForeignCommit>
Fetch a published commit from IPFS, decrypt it with a content key, and store all objects (commit, metadata, manifest, shards) in the local store.

This is the shared pipeline used by both fork and pull-request.