Merge base (LCA) computation for void repositories.
This module implements finding the lowest common ancestor (LCA) of two commits, which is used as the merge base for three-way merges.
Functions
- find_
merge_ base - Finds the merge base (lowest common ancestor) of two commits.