export_commit_to_car

Function export_commit_to_car 

pub fn export_commit_to_car<P: AsRef<Path>>(
    opts: ExportCarOptions,
    output_path: P,
) -> Result<ExportCarResult>
Export a commit and all its objects to a CAR file.

The CAR file can be transferred via SCP, HTTP, or any other method, then imported on a remote IPFS node with ipfs dag import.