Module shard

Module shard 

Shard storage for void

Shards are opaque zstd-compressed blobs of concatenated file contents. File indexing is handled by the TreeManifest, not the shard itself. Shards are like filesystem blocks — no headers, no metadata.

Structs

ShardBody
Decompressed shard body for manifest-driven file access.
ShardWriter
Builder for creating shards.

Enums

PaddingStrategy
Padding strategy for shard sizes.

Constants

DEFAULT_BUCKETS
Default bucket sizes for Buckets padding strategy.

Functions

calculate_padded_size
Calculates the target padded size for a given data size.
read_padding_info
Reads the padding size from the end of shard data.