read_padding_info

Function read_padding_info 

pub fn read_padding_info(data: &[u8]) -> Option<usize>
Reads the padding size from the end of shard data.

Returns None if this is an old format shard (no padding footer). Returns Some(padding_size) if a valid padding footer is found. Padded shards have a footer with: magic (8 bytes) + padding_size (8 bytes)