pub struct ShardWriter { /* private fields */ }Expand description
Builder for creating shards.
A shard is a zstd-compressed blob of concatenated file contents. File indexing is handled by the TreeManifest, not the shard itself. Shards are opaque blocks — like filesystem blocks.
Implementations
Sourceimpl ShardWriter
impl ShardWriter
Sourcepub fn finish(self, compression_level: i32) -> Result<Vec<u8>>
pub fn finish(self, compression_level: i32) -> Result<Vec<u8>>
Finishes building and returns the zstd-compressed shard bytes.
Errors
Returns VoidError::Compression if compression fails.
Sourcepub fn file_count(&self) -> u32
pub fn file_count(&self) -> u32
Returns the number of files added.
Sourcepub fn finish_padded(
self,
strategy: PaddingStrategy,
compression_level: i32,
) -> Result<Vec<u8>>
pub fn finish_padded( self, strategy: PaddingStrategy, compression_level: i32, ) -> Result<Vec<u8>>
Finishes building and returns serialized shard bytes with optional size padding.
Padding is applied to hide the true shard size from the server. The padding size is stored as a little-endian u64 at the end of the shard.
Errors
Returns VoidError::Compression if compression fails.