pub struct FsStore { /* private fields */ }Expand description
Filesystem-backed object store.
Objects are stored in a two-level directory structure:
objects/<prefix>/<cid>
Implementations
Sourceimpl FsStore
impl FsStore
Sourcepub fn new(root: impl Into<Utf8PathBuf>) -> Result<Self>
pub fn new(root: impl Into<Utf8PathBuf>) -> Result<Self>
Creates a new filesystem store at the given path.
Creates the directory if it doesn’t exist.
Sourcepub fn root(&self) -> &Utf8PathBuf
pub fn root(&self) -> &Utf8PathBuf
Returns the root directory path of this store.
Sourcepub fn object_path(root: &Path, cid_str: &str) -> PathBuf
pub fn object_path(root: &Path, cid_str: &str) -> PathBuf
Compute the filesystem path for a CID string within an objects directory.
Layout: <root>/<first-2-chars>/<full-cid-string>
This is the canonical path scheme for void object storage.
Used by FsStore, CliBlockStore, and the daemon files command.