stream_file

Function stream_file 

pub fn stream_file<'a, S: ObjectStoreExt>(
    store: &'a S,
    reader: &'a CommitReader,
    ancestor_keys: &'a [ContentKey],
    manifest: &'a TreeManifest,
    path: &str,
) -> Result<ShardStreamReader<'a, S>>
Open a streaming reader for a file in a commit.

Looks up the file in the manifest, determines which shards it spans, and returns a Read implementation that streams through them.