pub struct MultiObserver { /* private fields */ }Expand description
Observer that forwards events to multiple child observers.
Useful for composing multiple observers, such as logging to both a progress bar and a log file.
Implementations
Sourceimpl MultiObserver
impl MultiObserver
Sourcepub fn new(observers: Vec<Arc<dyn VoidObserver>>) -> Self
pub fn new(observers: Vec<Arc<dyn VoidObserver>>) -> Self
Create a new multi-observer from a list of child observers.
Arguments
observers- List of observers to forward events to.
Sourcepub fn add(&mut self, observer: Arc<dyn VoidObserver>)
pub fn add(&mut self, observer: Arc<dyn VoidObserver>)