pub struct ContentHash(pub [u8; 32]);Expand description
SHA-256 hash of file content.
Used in shard entries, manifest entries, index entries, and diffs to track file identity and detect modifications.
Tuple Fields
0: [u8; 32]Implementations
Sourceimpl ContentHash
impl ContentHash
Sourcepub fn from_bytes(bytes: [u8; 32]) -> Self
pub fn from_bytes(bytes: [u8; 32]) -> Self
Create from a raw 32-byte digest.