pub struct RepoLock { /* private fields */ }Expand description
A guard that holds the repository lock until dropped.
Implementations
Sourceimpl RepoLock
impl RepoLock
Sourcepub fn acquire(void_dir: &Path, force: bool) -> Result<Self>
pub fn acquire(void_dir: &Path, force: bool) -> Result<Self>
Acquire the repository lock, optionally forcing removal of a stale lock.
Sourcepub fn is_stale(void_dir: &Path) -> Result<Option<StaleLockInfo>>
pub fn is_stale(void_dir: &Path) -> Result<Option<StaleLockInfo>>
Check if an existing lock is stale (process no longer running).
Sourcepub fn acquire_auto(void_dir: &Path) -> Result<Self>
pub fn acquire_auto(void_dir: &Path) -> Result<Self>
Acquire lock, automatically removing stale locks.