Module workspace

Module workspace 

Working directory operations for void

Provides staging, checkout, status, and file operations for the workspace.

Re-exports

pub use checkout::checkout_paths;
pub use checkout::checkout_tree;
pub use checkout::CheckoutOptions;
pub use checkout::CheckoutStats;
pub use stage::stage_paths;
pub use stage::StageOptions;
pub use stage::StageResult;
pub use reset::reset_paths;
pub use reset::ResetOptions;
pub use reset::ResetResult;
pub use status::status_workspace;
pub use status::StatusOptions;
pub use status::StatusResult;
pub use remove::remove_paths;
pub use remove::RemoveOptions;
pub use remove::RemoveResult;
pub use move_path::move_path;
pub use move_path::MoveOptions;
pub use move_path::MoveResult;
pub use workspaces::create_workspace;
pub use workspaces::find_workspace_for_branch;
pub use workspaces::list_workspaces;
pub use workspaces::parse_void_file;
pub use workspaces::prune_workspaces;
pub use workspaces::remove_workspace;
pub use workspaces::WorkspaceInfo;

Modules

checkout
Checkout module - restore files from a commit to the working tree
move_path
Move/rename operations for workspace.
remove
Remove operations for workspace.
reset
Reset operations for workspace staging.
stage
Staging operations and shared helpers for workspace.
status
Status operations for workspace.
workspaces
Workspace management — create, list, remove, and prune linked workspaces.