Identity management — re-exported from void-crypto.
See void_crypto::identity for the implementation.
Structs
- Identity
- An identity containing signing, recipient, and optional Nostr keys
- Parsed
Identity - Parsed identity containing public keys and optional username.
Enums
- Identity
Error - Errors that can occur in identity operations
Functions
- derive_
repo_ owner_ signing_ key - Derive a per-repo owner Ed25519 signing key from an identity seed and repo ID.
- ecies_
unwrap_ key - Unwrap a repository key using the identity’s X25519 private key.
- ecies_
wrap_ key - Wrap a repository key using ECIES for a recipient’s X25519 public key.