Diff engine for void
Computes file-level differences between commits, trees, and working directories.
Re-exports
pub use content::content_diff_commits;pub use content::content_diff_index;pub use content::content_diff_staged;pub use content::content_diff_working;pub use content::ContentDiff;pub use content::DiffLine;pub use content::Hunk;
Modules
- content
- Content-level diff generation.
Structs
- Diff
Stats - Statistics about a diff.
- File
Diff - Represents a single file difference.
- Three
WayDiff - Result of a three-way diff operation.
- Tree
Diff - Collection of file differences between two trees.
Enums
- Diff
Kind - Type of change detected for a file.
- Side
- Which side made a change in a three-way diff.
- Three
WayStatus - Status of a file in a three-way diff.
Functions
- diff_
commits - Computes the diff between two commits.
- diff_
index - Computes the diff between the index and the working tree.
- diff_
staged - Computes diff between HEAD commit and the index.
- diff_
three_ way - Computes a three-way diff between a base commit and two branch commits.
- diff_
working - Computes the diff between a commit and the working tree.
Type Aliases
- Cid
- A Cid that contains a multihash with an allocated size of 512 bits.