pub struct VoidCid(/* private fields */);Expand description
A content identifier for void objects.
Wraps cid::Cid with void-specific constructors, validation, and a
Display implementation so CIDs can be used directly in format strings
without calling a separate to_string() helper.
All void CIDs are CIDv1 with raw codec (0x55) and SHA-256 multihash.
Implementations
Methods from Deref<Target = Cid>
Sourcepub fn write_bytes<W>(&self, w: W) -> Result<usize, Error>where
W: Write,
pub fn write_bytes<W>(&self, w: W) -> Result<usize, Error>where
W: Write,
Writes the bytes to a byte stream, returns the number of bytes written.
Sourcepub fn encoded_len(&self) -> usize
pub fn encoded_len(&self) -> usize
Returns the length in bytes needed to encode this cid into bytes.
Sourcepub fn to_string_of_base(&self, base: Base) -> Result<String, Error>
pub fn to_string_of_base(&self, base: Base) -> Result<String, Error>
Convert CID into a multibase encoded string
Example
use cid::Cid;
use multibase::Base;
use multihash_codetable::{Code, MultihashDigest};
const RAW: u64 = 0x55;
let cid = Cid::new_v1(RAW, Code::Sha2_256.digest(b"foo"));
let encoded = cid.to_string_of_base(Base::Base64).unwrap();
assert_eq!(encoded, "mAVUSICwmtGto/8aP+ZtFPB0wQTQTQi1wZIO/oPmKXohiZueu");Trait Implementations
Sourceimpl Ord for VoidCid
impl Ord for VoidCid
Sourceimpl PartialOrd for VoidCid
impl PartialOrd for VoidCid
impl Copy for VoidCid
impl Eq for VoidCid
impl StructuralPartialEq for VoidCid